==> client-0.4.0.tgz: package/lib/legacy-client.js <==
const Workspace = require('./workspace')
const { DEFAULT_COLLECTION } = require('./constants')
const SearchQueryBuilder = require('./searchquerybuilder')

module.exports = class LegacyClient extends Workspace {
  constructor (opts) {
    super(opts)
    this._focus = null
    this._defaultCollection = opts.collection || DEFAULT_COLLECTION
  }

  focusCollection (name) {
    this._focus = this.openCollection(name)
  }

  async focusedCollection () {
    if (!this._focus && this._defaultCollection) this.focusCollection(this._defaultCollection)
    this._focusedCollection = await this._focus
    return this._focus
  }

  // TODO: Remove.
  async getCurrentCollection () {
    return this.focusedCollection()
  }

  async info () {
    return this.fetch('/info')
  }

  async getTypes () {
    const collection = await this.focusedCollection()
    return collection.schema.getTypes()
  }

  async getType (name) {
    const collection = await this.focusedCollection()
    return collection.schema.getType(name)
  }

  async putType (name, schema) {
    schema.name = name
    const collection = await this.focusedCollection()
    return collection.putType(schema)
  }

  // TODO: Remove.
  getSchemas () {
    return this.getTypes()
  }

  getSchema (name) {
    return this.getType(name)
  }

  async putFeed (key, opts) {
    const collection = await this.focusedCollection()
    return collection.putFeed(key, opts)
  }

  async get (req, opts) {
    const collection = await this.focusedCollection()
    return collection.get(req, opts)
  }

  async put (record) {
    const collection = await this.focusedCollection()
    return collection.put(record)
  }

  async del (record) {
    const collection = await this.focusedCollection()
    return collection.del(record)
  }

  async sync (view) {
    const collection = await this.focusedCollection()
    return collection.sync(view)
  }

  async query (name, args, opts) {
    const collection = await this.focusedCollection()
    return collection.query(name, args, opts)
  }

  async search (args, opts) {
    if (typeof args === 'string') {
      args = JSON.stringify(args)
    } else if (args instanceof SearchQueryBuilder) {
      args = args.getQuery()
    }
    const collection = await this.focusedCollection()
    return collection.query('search', args, opts)
  }

  // FS methods
  async getDrives () {
    const collection = await this.focusedCollection()
    return collection.fs.listDrives()
  }

  async readdir (path) {
    const collection = await this.focusedCollection()
    return collection.fs.readdir(path)
  }

  async writeFile (path, file, opts) {
    const collection = await this.focusedCollection()
    return collection.fs.writeFile(path, file, opts)
  }

  async readFile (path, opts) {
    const collection = await this.focusedCollection()
    return collection.fs.readFile(path, opts)
  }

  async statFile (path) {
    const collection = await this.focusedCollection()
    return collection.fs.stat(path)
  }

  // Resources
  // TODO: Rethink the resource API and model
  async createResource (value, opts) {
    const collection = await this.focusedCollection()
    return collection.resources.create(value, opts)
  }

  async readResourceFile (record, opts) {
    const collection = await this.focusedCollection()
    return collection.resources.readFile(record, opts)
  }

  async writeResourceFile (record, file, opts) {
    const collection = await this.focusedCollection()
    return collection.resources.writeFile(record, file, opts)
  }

  async resolveResourceURL (record) {
    const collection = await this.focusedCollection()
    return collection.resources.resolveFileURL(record)
  }

  // Subscriptions
  async pullSubscription (name, opts) {
    const collection = await this.focusedCollection()
    return collection.pullSubscription(name, opts)
  }

  async ackSubscription (name, cursor) {
    const collection = await this.focusedCollection()
    return collection.ackSubscription(name, cursor)
  }
}

==> client-0.5.0.tgz: package/lib/legacy-client.js <==
const Workspace = require('./workspace')
const { DEFAULT_COLLECTION } = require('./constants')
const SearchQueryBuilder = require('./searchquerybuilder')

module.exports = class LegacyClient extends Workspace {
  constructor (opts) {
    super(opts)
    this._focus = null
    this._defaultCollection = opts.collection || DEFAULT_COLLECTION
  }

  focusCollection (name) {
    this._focus = this.openCollection(name)
  }

  async focusedCollection () {
    if (!this._focus && this._defaultCollection) this.focusCollection(this._defaultCollection)
    this._focusedCollection = await this._focus
    return this._focus
  }

  // TODO: Remove.
  async getCurrentCollection () {
    return this.focusedCollection()
  }

  async info () {
    return this.fetch('/')
  }

  async getTypes () {
    const collection = await this.focusedCollection()
    return collection.schema.getTypes()
  }

  async getType (name) {
    const collection = await this.focusedCollection()
    return collection.schema.getType(name)
  }

  async putType (name, schema) {
    schema.name = name
    const collection = await this.focusedCollection()
    return collection.putType(schema)
  }

  // TODO: Remove.
  getSchemas () {
    return this.getTypes()
  }

  getSchema (name) {
    return this.getType(name)
  }

  async putFeed (key, opts) {
    const collection = await this.focusedCollection()
    return collection.putFeed(key, opts)
  }

  async get (req, opts) {
    const collection = await this.focusedCollection()
    return collection.get(req, opts)
  }

  async put (record) {
    const collection = await this.focusedCollection()
    return collection.put(record)
  }

  async del (record) {
    const collection = await this.focusedCollection()
    return collection.del(record)
  }

  async sync (view) {
    const collection = await this.focusedCollection()
    return collection.sync(view)
  }

  async query (name, args, opts) {
    const collection = await this.focusedCollection()
    return collection.query(name, args, opts)
  }

  async search (args, opts) {
    if (typeof args === 'string') {
      args = JSON.stringify(args)
    } else if (args instanceof SearchQueryBuilder) {
      args = args.getQuery()
    }
    const collection = await this.focusedCollection()
    return collection.query('search', args, opts)
  }

  // FS methods
  async getDrives () {
    const collection = await this.focusedCollection()
    return collection.fs.listDrives()
  }

  async readdir (path) {
    const collection = await this.focusedCollection()
    return collection.fs.readdir(path)
  }

  async writeFile (path, file, opts) {
    const collection = await this.focusedCollection()
    return collection.fs.writeFile(path, file, opts)
  }

  async readFile (path, opts) {
    const collection = await this.focusedCollection()
    return collection.fs.readFile(path, opts)
  }

  async statFile (path) {
    const collection = await this.focusedCollection()
    return collection.fs.stat(path)
  }

  // Resources
  // TODO: Rethink the resource API and model
  async createResource (value, opts) {
    const collection = await this.focusedCollection()
    return collection.resources.create(value, opts)
  }

  async readResourceFile (record, opts) {
    const collection = await this.focusedCollection()
    return collection.resources.readFile(record, opts)
  }

  async writeResourceFile (record, file, opts) {
    const collection = await this.focusedCollection()
    return collection.resources.writeFile(record, file, opts)
  }

  async resolveResourceURL (record) {
    const collection = await this.focusedCollection()
    return collection.resources.resolveFileURL(record)
  }

  // Subscriptions
  async pullSubscription (name, opts) {
    const collection = await this.focusedCollection()
    return collection.pullSubscription(name, opts)
  }

  async ackSubscription (name, cursor) {
    const collection = await this.focusedCollection()
    return collection.ackSubscription(name, cursor)
  }
}
